@@ -57,50 +57,49 @@ exports.TradeoffAnalyticsV1 = require('./tradeoff-analytics/v1');
 
 exports.VisualRecognitionV3 = require('./visual-recognition/v3');
 
-
-
 // adding shim constructors for backwards compatibility
 
 // 2-d map of snake_case service names & version => constructor function
 // e.g. servicesByVersion.text_to_speech.v1 === exports.TextToSpeechV1;
-var servicesByVersion = {};
+const servicesByVersion = {};
 Object.keys(exports).forEach(function(key) {
-  var Service = exports[key];
-  var name = Service.prototype.name;
-  var version = Service.prototype.version;
+  const Service = exports[key];
+  const name = Service.prototype.name;
+  const version = Service.prototype.version;
   servicesByVersion[name] = servicesByVersion[name] || {};
   servicesByVersion[name][version] = Service;
 });
 
 Object.keys(servicesByVersion).forEach(function(serviceName) {
-    Object.defineProperty(exports, serviceName, {
-      enumerable: false,
-      configurable: true,
-      writable: true,
-      value: function(options) {
-        options = options || {};
+  Object.defineProperty(exports, serviceName, {
+    enumerable: false,
+    configurable: true,
+    writable: true,
+    value: function(options) {
+      options = options || {};
 
-        // previously, AlchemyAPI did not require a version to be specified
-        if(serviceName.indexOf('alchemy_') === 0) {
-          options.version = 'v1';
-        }
-
-        var Service = servicesByVersion[serviceName][options.version];
-
-        if (!Service) {
-          throw new Error('Unable to find ' + serviceName + ' version ' + options.version);
-        }
-
-        return new Service(options);
+      // previously, AlchemyAPI did not require a version to be specified
+      if (serviceName.indexOf('alchemy_') === 0) {
+        options.version = 'v1';
       }
+
+      const Service = servicesByVersion[serviceName][options.version];
+
+      if (!Service) {
+        throw new Error('Unable to find ' + serviceName + ' version ' + options.version);
+      }
+
+      return new Service(options);
+    }
   });
 });
 
 // removed services
 // we don't want these services listed (so non-enumerable), but we do want a clear error message
 // if old code happens to try using one
-['concept_insights', 'relationship_extraction', 'message_resonance', 'question_and_answer',
-'visual_insights', 'concept_expansion'].forEach(function(serviceName) {
+['concept_insights', 'relationship_extraction', 'message_resonance', 'question_and_answer', 'visual_insights', 'concept_expansion'].forEach(function(
+  serviceName
+) {
   Object.defineProperty(exports, serviceName, {
     enumerable: false,
     configurable: true,
