@@ -14,13 +14,11 @@
  * limitations under the License.
  */
 
-
-"use strict";
-var extend       = require('extend');
-var vcapServices = require('vcap_services');
-var helper       = require('./helper');
-var request      = require('request');
-
+'use strict';
+const extend = require('extend');
+const vcapServices = require('vcap_services');
+const helper = require('./helper');
+const request = require('request');
 
 /**
  * Internal base class that other services inherit from
@@ -40,14 +38,15 @@ function BaseService(user_options) {
     // it might be better to just create a new instance and return that.. but that can't be done here, it has to be done in each individual service. So this is still a good failsafe even in that case.
     throw new Error('"new" keyword required to create Watson service instances');
   }
-  var options = extend({}, user_options);
+  let options = extend({}, user_options);
 
   options = this.initCredentials(options);
 
-  if (options.url)
-    {options.url = helper.stripTrailingSlash(options.url);}
+  if (options.url) {
+    options.url = helper.stripTrailingSlash(options.url);
+  }
 
-  this._options = extend({qs: {}, url: this.constructor.URL}, this.serviceDefaults, options);
+  this._options = extend({ qs: {}, url: this.constructor.URL }, this.serviceDefaults, options);
 }
 
 /**
@@ -66,20 +65,17 @@ BaseService.prototype.initCredentials = function(options) {
 
   // Get credentials from environment properties or Bluemix
   // but prefer credentials provided pragmatically!
-  options = extend(
-    {},
-    this.getCredentialsFromBluemix(this.name),
-    this.getCredentialsFromEnvironment(this.name),
-    options
-  );
+  options = extend({}, this.getCredentialsFromBluemix(this.name), this.getCredentialsFromEnvironment(this.name), options);
 
   if (!options.use_unauthenticated) {
     if (!options.username || !options.password) {
-        throw new Error('Argument error: username and password are required unless use_unauthenticated is set');
+      throw new Error('Argument error: username and password are required unless use_unauthenticated is set');
     }
 
     // Calculate and add Authorization header to base options
-    var authHeader = {Authorization: 'Basic ' + new Buffer(options.username + ':' + options.password).toString('base64')};
+    const authHeader = {
+      Authorization: 'Basic ' + new Buffer(options.username + ':' + options.password).toString('base64')
+    };
     options.headers = extend(authHeader, options.headers);
   }
 
@@ -103,7 +99,7 @@ BaseService.prototype.getCredentialsFromEnvironment = function(name) {
     username: process.env[name + '_USERNAME'],
     password: process.env[name + '_PASSWORD'],
     url: process.env[name + '_URL']
-  }
+  };
 };
 
 /**
@@ -128,8 +124,7 @@ BaseService.prototype.getCredentials = function() {
     username: this._options.username,
     password: this._options.password,
     url: this._options.url
-  }
+  };
 };
 
-
 module.exports = BaseService;
