@@ -1,8 +1,8 @@
 'use strict';
 
-var util = require('util');
-var extend = require('extend');
-var BaseService = require('./base_service');
+const util = require('util');
+const extend = require('extend');
+const BaseService = require('./base_service');
 
 /**
  * Variation of BaseService for Alchemy API services (and Visual Recognition v3)
@@ -36,9 +36,9 @@ BaseServiceAlchemy.prototype.initCredentials = function(options) {
     }
     // Per documentation, Alchemy* services use `apikey`, but Visual Recognition uses (`api_key`)
     // (Either will work in most cases, but there are a few exceptions.)
-    options.qs = extend({ apikey : options.apikey }, options.qs);
+    options.qs = extend({ apikey: options.apikey }, options.qs);
   }
-  return options
+  return options;
 };
 
 /**
@@ -51,7 +51,7 @@ BaseServiceAlchemy.prototype.getCredentialsFromEnvironment = function(name) {
   return {
     apikey: process.env[name.toUpperCase() + '_API_KEY'],
     url: process.env[name + '_URL']
-  }
+  };
 };
 
 /**
@@ -63,7 +63,7 @@ BaseServiceAlchemy.prototype.getCredentials = function() {
   return {
     apikey: this._options.apikey,
     url: this._options.url
-  }
+  };
 };
 
 module.exports = BaseServiceAlchemy;
