@@ -16,14 +16,14 @@
 
 'use strict';
 
-var stringify = require('csv-stringify');
+const stringify = require('csv-stringify');
 
 function toCSVArray(data) {
-  if (data.text && data.classes && data.classes.length > 0)
-    {return [data.text].concat(data.classes);}
-  else
-    {throw Error('Invalid training_data format, it needs to be: '+
-      '[{ text: "my-text", classes:["my-class1", "my-class2",...]}, {}, ...]');}
+  if (data.text && data.classes && data.classes.length > 0) {
+    return [data.text].concat(data.classes);
+  } else {
+    throw Error('Invalid training_data format, it needs to be: ' + '[{ text: "my-text", classes:["my-class1", "my-class2",...]}, {}, ...]');
+  }
 }
 
 /**
@@ -38,6 +38,7 @@ module.exports = function toCSV(training, cb) {
     } catch (e) {
       cb(e);
     }
-  } else
-    {cb(null, training);}
+  } else {
+    cb(null, training);
+  }
 };
